@@ -48,7 +48,7 @@ impl AsyncReaderBuilder {
     ///     Ok(())
     /// }
     /// ```
-    pub fn create_deserializer<R: io::AsyncRead + std::marker::Unpin>(&self, rdr: R) -> AsyncDeserializer<R> {
+    pub fn create_deserializer<R: io::AsyncRead + Unpin + Send + Sync>(&self, rdr: R) -> AsyncDeserializer<R> {
         AsyncDeserializer::new(self, rdr)
     }
 }
@@ -63,7 +63,7 @@ impl AsyncReaderBuilder {
 /// # Configuration
 ///
 /// A CSV deserializer has convenient constructor method `from_reader`.
-/// and `from_reader`. However, if you want to configure the CSV deserializer to use
+/// However, if you want to configure the CSV deserializer to use
 /// a different delimiter or quote character (among many other things), then
 /// you should use a [`AsyncReaderBuilder`](struct.AsyncReaderBuilder.html) to construct
 /// a `AsyncDeserializer`. For example, to change the field delimiter:
@@ -141,7 +141,7 @@ pub struct AsyncDeserializer<R>(AsyncReaderImpl<R>);
 
 impl<'r, R> AsyncDeserializer<R>
 where
-    R: io::AsyncRead + std::marker::Unpin + 'r,
+    R: io::AsyncRead + Unpin + Send + Sync + 'r,
 {
     /// Create a new CSV reader given a builder and a source of underlying
     /// bytes.
