@@ -486,7 +486,7 @@ where
     /// records could be read.
     ///
     /// If `has_headers` was enabled via a `ReaderBuilder` (which is the
-    /// default), then this will never read the first record.
+    /// default), then this will treat initial row as headers and read the first data record.
     ///
     /// This method is useful when you want to read records as fast as
     /// as possible. It's less ergonomic than an iterator, but it permits the
@@ -528,7 +528,7 @@ where
     /// more records could be read.
     ///
     /// If `has_headers` was enabled via a `ReaderBuilder` (which is the
-    /// default), then this will never read the first record.
+    /// default), then this will treat initial row as headers and read the first data record.
     ///
     /// This method is useful when you want to read records as fast as
     /// as possible. It's less ergonomic than an iterator, but it permits the
@@ -678,6 +678,155 @@ where
     }
 }
 
+impl<R: io::AsyncRead + io::AsyncSeek + std::marker::Unpin> AsyncReader<R> {
+    /// Seeks the underlying reader to the position given.
+    ///
+    /// This comes with a few caveats:
+    ///
+    /// * Any internal buffer associated with this reader is cleared.
+    /// * If the given position does not correspond to a position immediately
+    ///   before the start of a record, then the behavior of this reader is
+    ///   unspecified.
+    /// * Any special logic that skips the first record in the CSV reader
+    ///   when reading or iterating over records is disabled.
+    ///
+    /// If the given position has a byte offset equivalent to the current
+    /// position, then no seeking is performed.
+    ///
+    /// If the header row has not already been read, then this will attempt
+    /// to read the header row before seeking. Therefore, it is possible that
+    /// this returns an error associated with reading CSV data.
+    ///
+    /// Note that seeking is performed based only on the byte offset in the
+    /// given position. Namely, the record or line numbers in the position may
+    /// be incorrect, but this will cause any future position generated by
+    /// this CSV reader to be similarly incorrect.
+    ///
+    /// # Example: seek to parse a record twice
+    ///
+    /// ```
+    /// # use tokio1 as tokio;
+    /// use std::error::Error;
+    /// use tokio::io;
+    /// use tokio_stream::StreamExt;
+    /// use csv_async::{AsyncReader, Position};
+    ///
+    /// # fn main() { tokio::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
+    /// async fn example() -> Result<(), Box<dyn Error>> {
+    ///     let data = "\
+    /// city,country,popcount
+    /// Boston,United States,4628910
+    /// Concord,United States,42695
+    /// ";
+    ///     let mut rdr = AsyncReader::from_reader(std::io::Cursor::new(data));
+    ///     let mut pos = Position::new();
+    ///     {
+    ///     let mut records = rdr.records();
+    ///     loop {
+    ///         let next = records.next().await;
+    ///         if let Some(next) = next {
+    ///             pos = next?.position().expect("Cursor should be at some valid position").clone();
+    ///         } else {
+    ///             break;
+    ///         }
+    ///     }
+    ///     }
+    ///
+    ///     {
+    ///     // Now seek the reader back to `pos`. This will let us read the
+    ///     // last record again.
+    ///     rdr.seek(pos).await?;
+    ///     let mut records = rdr.into_records();
+    ///     if let Some(result) = records.next().await {
+    ///         let record = result?;
+    ///         assert_eq!(record, vec!["Concord", "United States", "42695"]);
+    ///         Ok(())
+    ///     } else {
+    ///         Err(From::from("expected at least one record but got none"))
+    ///     }
+    ///     }
+    /// }
+    /// ```
+    #[inline]
+    pub async fn seek(&mut self, pos: Position) -> Result<()> {
+        self.0.seek(pos).await
+    }
+
+    /// This is like `seek`, but provides direct control over how the seeking
+    /// operation is performed via `io::SeekFrom`.
+    ///
+    /// The `pos` position given *should* correspond the position indicated
+    /// by `seek_from`, but there is no requirement. If the `pos` position
+    /// given is incorrect, then the position information returned by this
+    /// reader will be similarly incorrect.
+    ///
+    /// If the header row has not already been read, then this will attempt
+    /// to read the header row before seeking. Therefore, it is possible that
+    /// this returns an error associated with reading CSV data.
+    ///
+    /// Unlike `seek`, this will always cause an actual seek to be performed.
+    #[inline]
+    pub async fn seek_raw(
+        &mut self,
+        seek_from: io::SeekFrom,
+        pos: Position,
+    ) -> Result<()> {
+        self.0.seek_raw(seek_from, pos).await
+    }
+
+    /// Rewinds the underlying reader to first data record.
+    ///
+    /// Function is aware of header presence.
+    /// After `rewind` record iterators will return first data record (skipping header if present), while
+    /// after `seek(0)` they will return header row (even if `has_header` is set).
+    /// 
+    /// # Example: Reads the same data multiply times
+    ///
+    /// ```
+    /// # use tokio1 as tokio;
+    /// use std::error::Error;
+    /// use tokio::io;
+    /// use tokio_stream::StreamExt;
+    /// use csv_async::AsyncReader;
+    ///
+    /// # fn main() { tokio::runtime::Runtime::new().unwrap().block_on(async {example().await.unwrap()}); }
+    /// async fn example() -> Result<(), Box<dyn Error>> {
+    ///     let data = "\
+    /// city,country,popcount
+    /// Boston,United States,4628910
+    /// Concord,United States,42695
+    /// ";
+    ///     let mut rdr = AsyncReader::from_reader(std::io::Cursor::new(data));
+    ///     let mut output = Vec::new();
+    ///     loop {
+    ///         let mut records = rdr.records();
+    ///         while let Some(rec) = records.next().await {
+    ///             output.push(rec?);
+    ///         }
+    ///         if output.len() >= 6 {
+    ///             break;
+    ///         } else {
+    ///             drop(records);
+    ///             rdr.rewind().await?;
+    ///         }
+    ///     }
+    ///     assert_eq!(output, 
+    ///         vec![
+    ///             vec!["Boston", "United States", "4628910"],
+    ///             vec!["Concord", "United States", "42695"],
+    ///             vec!["Boston", "United States", "4628910"],
+    ///             vec!["Concord", "United States", "42695"],
+    ///             vec!["Boston", "United States", "4628910"],
+    ///             vec!["Concord", "United States", "42695"],
+    ///         ]);
+    ///     Ok(())
+    /// }
+    /// ```
+    #[inline]
+    pub async fn rewind(&mut self) -> Result<()> {
+        self.0.rewind().await
+    }
+}
 
 #[cfg(test)]
 mod tests {
@@ -1061,6 +1210,92 @@ mod tests {
         });
     }
 
+    #[test]
+    fn seek() {
+        Runtime::new().unwrap().block_on(async {
+            let data = b("foo,bar,baz\na,b,c\nd,e,f\ng,h,i");
+            let mut rdr = AsyncReaderBuilder::new().create_reader(std::io::Cursor::new(data));
+            rdr.seek(newpos(18, 3, 2)).await.unwrap();
+
+            let mut rec = StringRecord::new();
+
+            assert_eq!(18, rdr.position().byte());
+            assert!(rdr.read_record(&mut rec).await.unwrap());
+            assert_eq!(3, rec.len());
+            assert_eq!("d", &rec[0]);
+
+            assert_eq!(24, rdr.position().byte());
+            assert_eq!(4, rdr.position().line());
+            assert_eq!(3, rdr.position().record());
+            assert!(rdr.read_record(&mut rec).await.unwrap());
+            assert_eq!(3, rec.len());
+            assert_eq!("g", &rec[0]);
+
+            assert!(!rdr.read_record(&mut rec).await.unwrap());
+        });
+    }
+
+    // Test that we can read headers after seeking even if the headers weren't
+    // explicit read before seeking.
+    #[test]
+    fn seek_headers_after() {
+        Runtime::new().unwrap().block_on(async {
+            let data = b("foo,bar,baz\na,b,c\nd,e,f\ng,h,i");
+            let mut rdr = AsyncReaderBuilder::new().create_reader(std::io::Cursor::new(data));
+            rdr.seek(newpos(18, 3, 2)).await.unwrap();
+            assert_eq!(rdr.headers().await.unwrap(), vec!["foo", "bar", "baz"]);
+        });
+    }
+
+    // Test that we can read headers after seeking if the headers were read
+    // before seeking.
+    #[test]
+    fn seek_headers_before_after() {
+        Runtime::new().unwrap().block_on(async {
+            let data = b("foo,bar,baz\na,b,c\nd,e,f\ng,h,i");
+            let mut rdr = AsyncReaderBuilder::new().create_reader(std::io::Cursor::new(data));
+            let headers = rdr.headers().await.unwrap().clone();
+            rdr.seek(newpos(18, 3, 2)).await.unwrap();
+            assert_eq!(&headers, rdr.headers().await.unwrap());
+        });
+    }
+
+    // Test that even if we didn't read headers before seeking, if we seek to
+    // the current byte offset, then no seeking is done and therefore we can
+    // still read headers after seeking.
+    #[test]
+    fn seek_headers_no_actual_seek() {
+        Runtime::new().unwrap().block_on(async {
+            let data = b("foo,bar,baz\na,b,c\nd,e,f\ng,h,i");
+            let mut rdr = AsyncReaderBuilder::new().create_reader(std::io::Cursor::new(data));
+            rdr.seek(Position::new()).await.unwrap();
+            assert_eq!("foo", &rdr.headers().await.unwrap()[0]);
+        });
+    }
+
+    #[test]
+    fn rewind() {
+        Runtime::new().unwrap().block_on(async {
+            let data = b("foo,bar,baz\na,b,c\nd,e,f\ng,h,i");
+            let mut rdr = AsyncReaderBuilder::new().create_reader(std::io::Cursor::new(data));
+
+            let mut rec = StringRecord::new();
+            assert!(rdr.read_record(&mut rec).await.unwrap());
+            assert_eq!(3, rec.len());
+            assert_eq!("a", &rec[0]);
+
+            // assert_eq!(18, rdr.position().byte());
+            assert!(rdr.read_record(&mut rec).await.unwrap());
+            assert_eq!(3, rec.len());
+            assert_eq!("d", &rec[0]);
+
+            rdr.rewind().await.unwrap();
+
+            assert!(rdr.read_record(&mut rec).await.unwrap());
+            assert_eq!(3, rec.len());
+            assert_eq!("a", &rec[0]);
+        });
+    }
 
     // Test that position info is reported correctly in absence of headers.
     #[test]
